#include<vcg/complex/complex.h>
#include<vcg/complex/algorithms/create/platonic.h>
#include<wrap/io_trimesh/export_off.h>
using namespace vcg;

class MyVertex; class MyEdge; class MyFace;
struct MyUsedTypes : public UsedTypes<Use<MyVertex>   ::AsVertexType,
                                           Use<MyEdge>     ::AsEdgeType,
                                           Use<MyFace>     ::AsFaceType>{};

class MyVertex  : public Vertex< MyUsedTypes, vertex::Coord3f, vertex::Normal3f, vertex::BitFlags  >{};
class MyFace    : public Face<   MyUsedTypes, face::FFAdj,  face::VertexRef, face::BitFlags > {};
class MyEdge    : public Edge<   MyUsedTypes> {};

class MyMesh    : public tri::TriMesh< std::vector<MyVertex>, 
    std::vector<MyFace> , std::vector<MyEdge>  > {};

int main( int /*argc*/, char **/*argv*/ )
{
  MyMesh tot;
  
  int n = 36;
  int loop = 4;
  float deltaZ = 5;
  for(int i=0;i<n*loop;++i)
  {
    MyMesh m;
    tri::Hexahedron<MyMesh>(m);
    Matrix44f rot2,sca,rot,tra,combined;
    rot2.SetRotateDeg(i*180/n,Point3f(0,1,0));
    sca.SetScale(0.5,1,3);
    rot.SetRotateDeg(i*360/n,Point3f(0,0,1));
    tra.SetTranslate(Point3f(10,0,i*deltaZ/n));
    combined = rot*tra*rot2*sca;
    tri::UpdatePosition<MyMesh>::Matrix(m,combined);
    tri::Append<MyMesh,MyMesh>::Mesh(tot,m);
  }
  tri::io::ExporterOFF<MyMesh>::Save(tot,"out.off");
  
  printf("Input mesh  vn:%i fn:%i\n",tot.VN(),tot.FN());
  
  return 0;
}
